@@ -29,7 +29,7 @@
 class SkeletonResourcePrivate;
 class Skeleton;
 
-class ARTIKULATELIB_EXPORT SkeletonResource : public ResourceInterface
+class ARTIKULATECORE_EXPORT SkeletonResource : public ResourceInterface
 {
     Q_OBJECT
     void course(QString text);
@@ -38,7 +38,7 @@ public:
     /**
      * Create course resource from file.
      */
-    explicit SkeletonResource(ResourceManager *resourceManager, const KUrl &path);
+    explicit SkeletonResource(ResourceManager *resourceManager, const QUrl &path);
 
     /**
      * Create course resource from course.
@@ -84,7 +84,7 @@ public:
     /**
      * \return path to resource file
      */
-    virtual KUrl path() const;
+    virtual QUrl path() const;
 
     /**
      * \return reference to the loaded resource
